Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Miaou_driver_matrix.Matrix_cellSourceTerminal cell representation for the Matrix driver.
A cell represents a single character position on the terminal with its associated styling (colors, bold, dim, etc.).
type style = {fg : int;Foreground color: -1 = default, 0-255 = 256-color palette
*)bg : int;Background color: -1 = default, 0-255 = 256-color palette
*)bold : bool;dim : bool;underline : bool;reverse : bool;url : string;OSC 8 hyperlink URL, "" = no link
*)}Style attributes for a cell.
type t = {mutable char : string;UTF-8 grapheme cluster, " " for empty/space
*)mutable style : style;}A terminal cell containing a character and its style.
Invalidate a cell so it never equals any valid cell. Used for force-redraw scenarios where we need to ensure the diff outputs changes even for cells that might otherwise appear unchanged. Sets char to \x00 which never appears in normal content.